GS1 Barcode
###########

Allows to calculate `GS1 <https://www.gs1.org>`_ barcode:

* Can calculate check digit for given GS1 barcode number.
* Can generate GS1 barcode number using company prefix and serial number.
